// MockLineReader.java
//
// Informatics 43 Spring 2009
// Code Example: Unit Testing with JUnit
//
// A MockLineReader is a kind of "fake" LineReader.  Rather than reading its
// input from some input source (e.g., a file, a network connection), it
// instead is given an ArrayList of Strings; it returns those Strings in
// sequence until there are none left.
//
// We'll use this in unit tests, though not otherwise.  MockLineReader's
// job is to be a "stand in" for an input file, so that unit tests won't
// depend on the presence of some file in order to work correctly.

import java.util.ArrayList;


public class MockLineReader implements LineReader
{
	private ArrayList<String> lines;
	private int index;
	
	
	public MockLineReader(ArrayList<String> lines)
	{
		this.lines = lines;
		index = 0;
	}
	
	
	public boolean hasNextLine()
	{
		return index < lines.size();
	}
	
	
	public String nextLine()
	{
		String line = lines.get(index);
		index++;
		return line;
	}
}
