// SongCollectionReader.java
//
// Informatics 43 Spring 2009
// Code Example: Unit Testing with JUnit
//
// This class implements the ability to read a song collection from an input
// source such as a file.  The input source is read one line at a time, with
// artists and titles appearing on consecutive lines.  So, for example, if
// the input source looks like this:
//
//     U2
//     Moment of Surrender
//     Peter Gabriel
//     Signal to Noise
//
// then the readSongCollection() method will return a SongCollection containing
// two Song objects: one with artist "U2" and title "Moment of Surrender" and
// the other with artist "Peter Gabriel" and title "Signal to Noise".
//
// Note that this class knows nothing about where it gets its input from.
// There are no FileReaders or Scanners here; instead, there's something of
// our own creation called a LineReader, which knows how to give back one
// line of input at a time from some source.
//
// An InputFormatException is thrown if the last entry has an artist but no
// title.

public class SongCollectionReader
{
	public SongCollection readSongCollection(LineReader lineReader)
	{
		SongCollection collection = new SongCollection();
		
		while (lineReader.hasNextLine())
		{
			String artist = lineReader.nextLine();
			
			if (!lineReader.hasNextLine())
			{
				throw new InputFormatException();
			}
			
			String title = lineReader.nextLine();
			
			collection.addSong(new Song(artist, title));
		}
		
		return collection;
	}
}
