// SongCollectionReaderTest.java
//
// Informatics 43 Spring 2009
// Code Example: Unit Testing with JUnit
//
// This class contains unit tests for our SongCollectionReader class.  Note
// the use of a MockLineReader in each test, which allows these unit tests
// to be run without requiring an input file to be present.
//
// The goal of unit testing is to test things out of context, so that we
// know whether they work independent of other things.  It's important that
// they're able to run without depending on external entities (such as files,
// databases, web sites, etc.).  So we "fake" the input files, rather than
// using actual ones.  When we use SongCollectionReader in an actual program,
// we'll pass it a file instead of a fake; but for unit testing purposes, a
// fake is exactly what we want.

import java.util.ArrayList;
import org.junit.*;
import static org.junit.Assert.*;


public class SongCollectionReaderTest
{
	@Test
	public void ifInputSourceIsEmptyReaderReturnsEmptyCollection()
	{
		MockLineReader emptyInputSource =
			new MockLineReader(new ArrayList<String>());
		
		SongCollection collection =
			new SongCollectionReader().readSongCollection(emptyInputSource);
		
		assertEquals(0, collection.getSongCount());
	}
	
	
	@Test
	public void ifInputSourceContainsOneArtistAndOneTitleACollectionWithOneSongIsReturned()
	{
		ArrayList<String> lines = new ArrayList<String>();
		lines.add("U2");
		lines.add("Moment of Surrender");
		
		MockLineReader inputSource = new MockLineReader(lines);
		
		SongCollection collection =
			new SongCollectionReader().readSongCollection(inputSource);
		
		assertEquals(1, collection.getSongCount());
	}
	
	
	@Test(expected = InputFormatException.class)
	public void failsWhenThereIsAMissingTitleAtTheEnd()
	{
		ArrayList<String> lines = new ArrayList<String>();
		lines.add("U2");
		
		MockLineReader inputSource = new MockLineReader(lines);
		
		new SongCollectionReader().readSongCollection(inputSource);
	}
}
