// SongCollectionTest.java
//
// Informatics 43 Spring 2009
// Code Example: Unit Testing with JUnit
//
// This class implements unit tests for the SongCollection class.  The only
// thing that our SongCollection presently knows how to do is to keep track
// of how many songs are in the collection as we add new songs, so that's the
// only functionality we've tested here.
//
// Note the use of a SongFactory to create new songs.  This is done to hide
// the details of how songs are created, so that we can change these details
// (e.g., add a parameter to Song's constructor) without affecting any of
// these tests.


// These imports are useful in classes that contain JUnit tests.
import org.junit.*;
import static org.junit.Assert.*;


public class SongCollectionTest
{
	private SongCollection collection;
	private SongFactory songFactory;
	

	// "Before" methods are executed automatically before each test, as a way
	// of setting a test up.  If many tests share some of the same "setting up"
	// code, such as creating necessary objects, before methods are a good
	// place to put that code, so that it doesn't have to be duplicated.
	// Here, we're creating a new SongCollection that can be used in each
	// test, storing it in a field, so that it will still be available when
	// the test method is called after this before method returns.
	@Before
	public void createSongCollection()
	{
		collection = new SongCollection();
	}
	
	
	@Before
	public void createSongFactory()
	{
		songFactory = new SongFactory();
	}
	
	
	@Test
	public void newlyCreatedCollectionsHaveSongCountZero()
	{
		assertEquals(0, collection.getSongCount());
	}
	
	
	@Test
	public void afterAddingASongToAnEmptyCollectionTheSongCountIsOne()
	{
		collection.addSong(songFactory.createSong());
		assertEquals(1, collection.getSongCount());
	}
	
	
	@Test
	public void afterAddingMultipleSongsTheSongCountKeepsGrowing()
	{
		for (int i = 1; i <= 100; i++)
		{
			collection.addSong(songFactory.createSong());
			assertEquals(i, collection.getSongCount());
		}
	}
}
