// SongFactory.java
//
// Informatics 43 Spring 2009
// Code Example: Unit Testing with JUnit
//
// In object-oriented programming (as we write in Java), "factories" are
// objects that construct and return other objects for us.  It may seem a
// little bit silly to write a class just to create Songs, but we're actually
// hiding an important detail: What parameters does the Song constructor
// require?  By hiding these details, we're allowing ourselves to change
// them without affecting any code (e.g., code in our unit tests).  In this
// case, we write separate methods to create Songs given only the things
// we might be interested in specifying, with anything else filled in
// with a "bogus" value automatically.

public class SongFactory
{
	// We use this count to make different automatically-generated artists
	// and titles unique.  Each time we generate an artist or a title, we
	// increment the count and include it in the name.
	private int count;
	
	
	public SongFactory()
	{
		count = 0;
	}
	

	// createSong() creates a new Song with an automatically-generated artist
	// and title.  This is used when you need to create a Song but don't care
	// about its artist and title.  (Some tests in SongCollectionTest do this.)
	public Song createSong()
	{
		return new Song(buildArtist(), buildTitle());
	}
	

	// createSongWithArtist() creates a new Song with the given artist and an
	// automatically-generated title.  (A test in SongTest does this.)
	public Song createSongWithArtist(String artist)
	{
		return new Song(artist, buildTitle());
	}
	
	
	// createSongWithTitle() creates a new Song with the given title and an
	// automatically-generated artist.  (A test in SongTest does this.)
	public Song createSongWithTitle(String title)
	{
		return new Song(buildArtist(), title);
	}
	

	// buildArtist() is used to automatically generate a unique artist whenever
	// one hasn't been specified.
	private String buildArtist()
	{
		count++;
		return "Artist" + count;
	}
	
	
	// buildTitle() is used to automatically generate a unique title whenever
	// one hasn't been specified.
	private String buildTitle()
	{
		count++;
		return "Title" + count;
	}
}
